/* General */
a:focus, .wp-core-ui .button-link:focus,
.wp-core-ui .button-secondary:focus, .wp-core-ui .button.focus,
.wp-core-ui .button:focus { -webkit-box-shadow: none; box-shadow: none; }
.wp-core-ui .button-link:focus,
.wp-core-ui .button-secondary:focus, .wp-core-ui .button.focus,
.wp-core-ui .button:focus { border-color: #999; }
.wrap .oceanwp-desc { padding: 10px 15px; margin: 12px 0 25px; }
.wrap .oceanwp-callout { background-color: #fff; color: #444; border: 1px solid #e5e5e5; padding: 22px 20px; border-radius: 3px; box-shadow: 0 1px 1px rgba(0,0,0,.04); }
.wrap .oceanwp-callout p { margin: 0; }

/* Plugins */
.oe-plugin-installer { box-sizing: border-box; display: -webkit-box; display: -moz-box; display: -ms-flexbox; display: -webkit-flex; display: flex; -webkit-flex-wrap: wrap; flex-wrap: wrap; flex-flow: row wrap; -webkit-flex-flow: row wrap; justify-content: space-between; width: 102%; position: relative; left: -1%; }
.oe-plugin-installer:after { content: ''; flex: auto; }
.oe-plugin-installer * { box-sizing: border-box; }
.oe-plugin-installer .plugin { width: 31.333%; margin: 0 1% 30px; padding: 0; overflow: hidden; text-align: left; border: 1px solid #e1e1e1; background: #fff; position: relative; border-radius: 2px; }
.oe-plugin-installer .plugin:hover { border-color: #cecece; }
.oe-plugin-installer .plugin-wrap { padding: 20px 20px 95px 145px; min-height: 214px; display: block; position: relative; }
.oe-plugin-installer li a,
.oe-plugin-installer .plugin-wrap a { text-decoration: none; }
.oe-plugin-installer .plugin-wrap img { display: block; position: absolute; left: 20px; top: 20px; max-width: 108px; max-height: 108px; border: 1px solid #f7f7f7; }
.oe-plugin-installer .plugin-wrap h2,
.oe-plugin-installer .plugin-wrap p { padding: 0; margin: 0; font-size: 17px; font-weight: 600; color: #333; line-height: 1.4; }
.oe-plugin-installer .plugin-wrap p { padding: 10px 0 0; margin: 0; font-size: 14px; font-weight: 400; color: #777; }
.oe-plugin-installer .plugin-wrap p.plugin-author { font-size: 13px; padding-top: 20px; font-style: italic; }
.oe-plugin-installer .activation-row { display: block; margin: 0; padding: 20px; background: #f7f7f7; border-top: 1px solid #e1e1e1; border-radius: 0 0 2px 2px; position: absolute; bottom: 0; width: 100%; overflow: hidden; border-radius: 0 0 2px 2px; text-align: left; }
.oe-plugin-installer .activation-row li { display: inline-block; vertical-align: top; margin: 0 10px 0 0; font-size: 13px; line-height: 27px; }

/* Ribbon */
.oe-plugin-installer li.ribbon { float: right; background-color: #67ce6b; color: #fff; padding: 0 10px; font-size: 12px; font-weight: 600; letter-spacing: 1px; text-align: center; text-transform: uppercase; border-radius: 3px; margin: 0; }

/* Notice */
.oceanwp-admin-notice { display: inline-block; -webkit-box-sizing: border-box; -moz-box-sizing: border-box; box-sizing: border-box; margin: 12px 0 25px; padding: 12px 16px; width: 100%; box-shadow: 0 1px 1px rgba(0,0,0,.04); border: 1px solid #e5e5e5; background-color: #fff; color: #555; font-size: 13px; }
.oceanwp-admin-notice .alignleft { font-size: 15px; line-height: 38px; }
.oceanwp-admin-notice a.button-primary { height: auto; font-size: 13px; font-weight: 600; line-height: 1; background-color: #13aff0; border: 0; color: #fff; padding: 12px 25px; text-transform: uppercase; letter-spacing: 1px; border-radius: 30px; text-align: center; transition: all .3s ease; -webkit-transition: all .3s ease; -moz-transition: all .3s ease; -o-transition: all .3s ease; -ms-transition: all .3s ease; text-shadow: none; -webkit-box-shadow: none; box-shadow: none; }
.oceanwp-admin-notice a.button-primary:hover { background-color: #0b7cac; }
.oceanwp-admin-notice a.button-secondary { opacity: 0.7 }
.oceanwp-admin-notice a.button-secondary:hover { opacity: 0.9 }
.oceanwp-admin-notice a { text-decoration: none;color: #3ba1da }
.oceanwp-admin-notice a:hover { color: #44b0ec }

/* RTL */
body.rtl .oe-plugin-installer { right: -1%; left: auto; }
body.rtl .oe-plugin-installer .plugin { text-align: right; }
body.rtl .oe-plugin-installer .plugin-wrap { padding: 20px 145px 95px 20px; }
body.rtl .oe-plugin-installer .plugin-wrap img { right: 20px; left: auto; }
body.rtl .oe-plugin-installer .activation-row { border-radius: 0 2px 2px 0; border-radius: 0 2px 2px 0; text-align: right; }
body.rtl .oe-plugin-installer .activation-row li { margin: 0 0 0 10px; }
body.rtl .oe-plugin-installer li.ribbon { float: left; }

/* Responsive */
@media only screen and (max-width: 1280px) {
    .oceanwp-admin-notice { text-align: center; }
    .oceanwp-admin-notice .alignleft,
    .oceanwp-admin-notice .alignright { float: none; }
    .oceanwp-admin-notice .alignleft { line-height: 1.5; }
    .oceanwp-admin-notice a.button-primary { margin: 15px 0 5px; }
}

@media screen and (max-width: 1170px) {
   .oe-plugin-installer .plugin { width: 48%; margin: 0 1% 15px; }
}

@media screen and (max-width: 960px) {
   .oe-plugin-installer .plugin-wrap { padding: 20px 20px 95px 115px; min-height: 214px; }
   .oe-plugin-installer .plugin-wrap img { max-width: 78px; max-height: 78px; }
   body.rtl .oe-plugin-installer .plugin-wrap { padding: 20px 115px 95px 20px; }
}

@media screen and (max-width: 640px) {
   .oe-plugin-installer { width: 100%; position: static; }
   .oe-plugin-installer .plugin { width: 100%; margin: 0 0 20px; }
}

@media only screen and (max-width: 320px) {
    .oceanwp-admin-notice a.button-primary { padding: 12px 18px; }
}